# Backers via Patreon

## Generous backers ($30+)

Name | Twitter | Website
--- | --- | ---
Roman Chvanikoff |  |
Garry Newman | @garrynewman |
Bjørn Nese |  |
Adrian Ocneanu | @aocneanu | Earthlink
Aaron | @aequasi |
wingerdkm1 | GitHub

## Documentation sponsors ($500+)

Name | Twitter | Website
--- | --- | ---
Tipe | @tipeio |

## Homepage sponsors ($100+)

Name | Twitter | Website
--- | --- | ---
Yiannakis Ttafounas |  |
Tooltwist |  |
Sparheld International GmbH |  |
Robert Bolder |  |
Phil Alves | @philalves01 |
Iaroslav Baklan |  |
DontPayFull |  |
patrick136 | GitHub
airtract | GitHub

## Bulma backers ($10+)

Name | Twitter | Website
--- | --- | ---
Tyler Weeres | @tweeres04 |
Takayuki Yamaguchi | @takyam |
Stuart Stanfield |  |
Maurice Perry |  |
Leo Zeba | @leozeba |
Jordan Nemrow |  |
Jason Seminara |  |
Florian Breisch | @FlorianBreisch |
dvkt |  |
Dodzidenu Dzakuma |  |
Gomah | GitHub
sasmithjr | GitHub
kuwaitbinary | GitHub